@@ -142,11 +142,11 @@ asb_test_package_rpm_func (void)
 	rel = g_ptr_array_index (releases, 0);
 	g_assert (rel != NULL);
 	g_assert_cmpstr (as_release_get_version (rel), ==, "0.1");
-	g_assert_cmpint (as_release_get_timestamp (rel), ==, 1274097600);
+	g_assert_cmpint ((gint64) as_release_get_timestamp (rel), ==, 1274097600);
 	g_assert_cmpstr (as_release_get_description (rel, NULL), ==, NULL);
 	rel = asb_package_get_release (pkg, "0.1");
 	g_assert (rel != NULL);
-	g_assert_cmpint (as_release_get_timestamp (rel), ==, 1274097600);
+	g_assert_cmpint ((gint64) as_release_get_timestamp (rel), ==, 1274097600);
 
 	/* check config */
 	g_assert_cmpstr (asb_package_get_config (pkg, "test"), ==, NULL);
@@ -425,7 +425,7 @@ asb_test_context_test_func (AsbTestContextMode mode)
 	/* check it matches what we expect */
 	xml = as_store_to_xml (store, AS_NODE_TO_XML_FLAG_FORMAT_MULTILINE);
 	expected_xml =
-		"<components version=\"0.9\" builder_id=\"appstream-glib:4\" origin=\"asb-self-test\">\n"
+		"<components builder_id=\"appstream-glib:4\" origin=\"asb-self-test\" version=\"0.9\">\n"
 #ifdef HAVE_FONTS
 		"<component type=\"font\">\n"
 		"<id>Liberation</id>\n"
@@ -435,7 +435,7 @@ asb_test_context_test_func (AsbTestContextMode mode)
 		"<name>Liberation</name>\n"
 		"<summary>Open source versions of several commecial fonts</summary>\n"
 		"<description><p>The Liberation Fonts are intended to be replacements for Times New Roman, Arial, and Courier New.</p></description>\n"
-		"<icon height=\"64\" width=\"64\" type=\"cached\">LiberationSerif.png</icon>\n"
+		"<icon type=\"cached\" height=\"64\" width=\"64\">LiberationSerif.png</icon>\n"
 		"<categories>\n"
 		"<category>Addons</category>\n"
 		"<category>Fonts</category>\n"
@@ -453,7 +453,7 @@ asb_test_context_test_func (AsbTestContextMode mode)
 		"</screenshot>\n"
 		"</screenshots>\n"
 		"<releases>\n"
-		"<release version=\"1\" timestamp=\"1407844800\"/>\n"
+		"<release timestamp=\"1407844800\" version=\"1\"/>\n"
 		"</releases>\n"
 		"<languages>\n"
 		"<lang>en</lang>\n"
@@ -477,7 +477,7 @@ asb_test_context_test_func (AsbTestContextMode mode)
 		"<url type=\"homepage\">http://people.freedesktop.org/</url>\n"
 		"<extends>app.desktop</extends>\n"
 		"<releases>\n"
-		"<release version=\"1\" timestamp=\"1407844800\"/>\n"
+		"<release timestamp=\"1407844800\" version=\"1\"/>\n"
 		"</releases>\n"
 		"<provides>\n"
 		"<dbus type=\"session\">org.freedesktop.AppStream</dbus>\n"
@@ -496,7 +496,7 @@ asb_test_context_test_func (AsbTestContextMode mode)
 		"<name>App</name>\n"
 		"<summary>A test application</summary>\n"
 		"<description><p>Long description goes here.</p></description>\n"
-		"<icon height=\"64\" width=\"64\" type=\"cached\">app.png</icon>\n"
+		"<icon type=\"cached\" height=\"64\" width=\"64\">app.png</icon>\n"
 		"<categories>\n"
 		"<category>Profiling</category>\n"
 		"<category>System</category>\n"
@@ -518,7 +518,7 @@ asb_test_context_test_func (AsbTestContextMode mode)
 		"</screenshot>\n"
 		"</screenshots>\n"
 		"<releases>\n"
-		"<release version=\"1\" timestamp=\"1407844800\"/>\n"
+		"<release timestamp=\"1407844800\" version=\"1\"/>\n"
 		"</releases>\n"
 		"<provides>\n"
 		"<dbus type=\"session\">org.freedesktop.AppStream</dbus>\n"
@@ -542,10 +542,10 @@ asb_test_context_test_func (AsbTestContextMode mode)
 		"<project_license>GPL-2.0+</project_license>\n"
 		"<url type=\"homepage\">http://www.hughski.com/</url>\n"
 		"<releases>\n"
-		"<release version=\"2.0.2\" timestamp=\"1424116753\">\n"
+		"<release timestamp=\"1424116753\" version=\"2.0.2\">\n"
 		"<location>http://www.hughski.com/downloads/colorhug2/firmware/colorhug-2.0.2.cab</location>\n"
-		"<checksum filename=\"colorhug-als-2.0.2.cab\" target=\"container\" type=\"sha1\">" AS_TEST_WILDCARD_SHA1 "</checksum>\n"
-		"<checksum filename=\"firmware.bin\" target=\"content\" type=\"sha1\">" AS_TEST_WILDCARD_SHA1 "</checksum>\n"
+		"<checksum type=\"sha1\" filename=\"colorhug-als-2.0.2.cab\" target=\"container\">" AS_TEST_WILDCARD_SHA1 "</checksum>\n"
+		"<checksum type=\"sha1\" filename=\"firmware.bin\" target=\"content\">" AS_TEST_WILDCARD_SHA1 "</checksum>\n"
 		"<description><p>This unstable release adds the following features:</p>"
 		"<ul><li>Add TakeReadingArray to enable panel latency measurements</li>"
 		"<li>Speed up the auto-scaled measurements considerably, using 256ms "
@@ -582,7 +582,7 @@ asb_test_context_test_func (AsbTestContextMode mode)
 	/* check output */
 	xml_failed = as_store_to_xml (store_failed, AS_NODE_TO_XML_FLAG_FORMAT_MULTILINE);
 	expected_xml =
-		"<components version=\"0.9\" builder_id=\"appstream-glib:4\" origin=\"asb-self-test-failed\">\n"
+		"<components builder_id=\"appstream-glib:4\" origin=\"asb-self-test-failed\" version=\"0.9\">\n"
 #ifdef HAVE_FONTS
 		"<component type=\"font\">\n"
 		"<id>LiberationSerif</id>\n"
@@ -590,7 +590,7 @@ asb_test_context_test_func (AsbTestContextMode mode)
 		"<source_pkgname>font</source_pkgname>\n"
 		"<name>Liberation Serif</name>\n"
 		"<summary>A Bold font from Liberation Serif</summary>\n"
-		"<icon height=\"64\" width=\"64\" type=\"cached\">LiberationSerif.png</icon>\n"
+		"<icon type=\"cached\" height=\"64\" width=\"64\">LiberationSerif.png</icon>\n"
 		"<categories>\n"
 		"<category>Addons</category>\n"
 		"<category>Fonts</category>\n"
@@ -612,7 +612,7 @@ asb_test_context_test_func (AsbTestContextMode mode)
 		"</screenshot>\n"
 		"</screenshots>\n"
 		"<releases>\n"
-		"<release version=\"1\" timestamp=\"1407844800\"/>\n"
+		"<release timestamp=\"1407844800\" version=\"1\"/>\n"
 		"</releases>\n"
 		"<languages>\n"
 		"<lang>en</lang>\n"
@@ -639,7 +639,7 @@ asb_test_context_test_func (AsbTestContextMode mode)
 		"<url type=\"homepage\">http://people.freedesktop.org/</url>\n"
 		"<extends>app.desktop</extends>\n"
 		"<releases>\n"
-		"<release version=\"1\" timestamp=\"1407844800\"/>\n"
+		"<release timestamp=\"1407844800\" version=\"1\"/>\n"
 		"</releases>\n"
 		"<provides>\n"
 		"<dbus type=\"session\">org.freedesktop.AppStream</dbus>\n"
@@ -668,7 +668,7 @@ asb_test_context_test_func (AsbTestContextMode mode)
 	/* check output */
 	xml_ignore = as_store_to_xml (store_ignore, AS_NODE_TO_XML_FLAG_FORMAT_MULTILINE);
 	expected_xml =
-		"<components version=\"0.9\" builder_id=\"appstream-glib:4\" origin=\"asb-self-test-ignore\">\n"
+		"<components builder_id=\"appstream-glib:4\" origin=\"asb-self-test-ignore\" version=\"0.9\">\n"
 		"<component type=\"generic\">\n"
 		"<id>app-console.noarch</id>\n"
 		"<pkgname>app-console</pkgname>\n"
@@ -847,7 +847,7 @@ asb_test_firmware_func (void)
 	/* check it matches what we expect */
 	xml = as_store_to_xml (store, AS_NODE_TO_XML_FLAG_FORMAT_MULTILINE);
 	expected_xml =
-		"<components version=\"0.9\" origin=\"asb-self-test\">\n"
+		"<components origin=\"asb-self-test\" version=\"0.9\">\n"
 		"<component type=\"firmware\">\n"
 		"<id>com.hughski.ColorHug2.firmware</id>\n"
 		"<name>ColorHug Firmware</name>\n"
@@ -858,10 +858,10 @@ asb_test_firmware_func (void)
 		"<project_license>GPL-2.0+</project_license>\n"
 		"<url type=\"homepage\">http://www.hughski.com/</url>\n"
 		"<releases>\n"
-		"<release version=\"2.0.2\" timestamp=\"1424116753\">\n"
+		"<release timestamp=\"1424116753\" version=\"2.0.2\">\n"
 		"<location>http://www.hughski.com/downloads/colorhug2/firmware/colorhug-2.0.2.cab</location>\n"
-		"<checksum filename=\"colorhug-als-2.0.2.cab\" target=\"container\" type=\"sha1\">" AS_TEST_WILDCARD_SHA1 "</checksum>\n"
-		"<checksum filename=\"firmware.bin\" target=\"content\" type=\"sha1\">" AS_TEST_WILDCARD_SHA1 "</checksum>\n"
+		"<checksum type=\"sha1\" filename=\"colorhug-als-2.0.2.cab\" target=\"container\">" AS_TEST_WILDCARD_SHA1 "</checksum>\n"
+		"<checksum type=\"sha1\" filename=\"firmware.bin\" target=\"content\">" AS_TEST_WILDCARD_SHA1 "</checksum>\n"
 		"<description><p>This unstable release adds the following features:</p>"
 		"<ul><li>Add TakeReadingArray to enable panel latency measurements</li>"
 		"<li>Speed up the auto-scaled measurements considerably, using 256ms "
@@ -869,10 +869,10 @@ asb_test_firmware_func (void)
 		"<size type=\"installed\">14</size>\n"
 		"<size type=\"download\">2011</size>\n"
 		"</release>\n"
-		"<release version=\"2.0.1\" timestamp=\"1424116753\">\n"
+		"<release timestamp=\"1424116753\" version=\"2.0.1\">\n"
 		"<location>http://www.hughski.com/downloads/colorhug2/firmware/colorhug-2.0.1.cab</location>\n"
-		"<checksum filename=\"colorhug-als-2.0.1.cab\" target=\"container\" type=\"sha1\">" AS_TEST_WILDCARD_SHA1 "</checksum>\n"
-		"<checksum filename=\"firmware.bin\" target=\"content\" type=\"sha1\">" AS_TEST_WILDCARD_SHA1 "</checksum>\n"
+		"<checksum type=\"sha1\" filename=\"colorhug-als-2.0.1.cab\" target=\"container\">" AS_TEST_WILDCARD_SHA1 "</checksum>\n"
+		"<checksum type=\"sha1\" filename=\"firmware.bin\" target=\"content\">" AS_TEST_WILDCARD_SHA1 "</checksum>\n"
 		"<description><p>This unstable release adds the following features:</p>"
 		"<ul><li>Use TakeReadings() to do a quick non-adaptive measurement</li>"
 		"<li>Scale XYZ measurement with a constant factor to make the CCMX more "
