@@ -486,7 +486,7 @@ ai_app_validate_image_check (AsImage *im, AsAppValidateHelper *helper)
 
 	/* create a buffer with the data */
 	stream = g_memory_input_stream_new_from_data (msg->response_body->data,
-						      msg->response_body->length,
+						      (gssize) msg->response_body->length,
 						      NULL);
 	if (stream == NULL) {
 		ai_app_validate_add (helper,
@@ -709,7 +709,8 @@ as_app_validate_icons (AsApp *app, AsAppValidateHelper *helper)
 		break;
 	case AS_ICON_KIND_LOCAL:
 		icon_name = as_icon_get_filename (icon);
-		if (!g_str_has_prefix (icon_name, "/")) {
+		if (icon_name == NULL ||
+		    !g_str_has_prefix (icon_name, "/")) {
 			ai_app_validate_add (helper,
 					     AS_PROBLEM_KIND_TAG_INVALID,
 					     "local icon is not a filename [%s]",
@@ -718,7 +719,8 @@ as_app_validate_icons (AsApp *app, AsAppValidateHelper *helper)
 		break;
 	case AS_ICON_KIND_CACHED:
 		icon_name = as_icon_get_name (icon);
-		if (g_str_has_prefix (icon_name, "/")) {
+		if (icon_name == NULL ||
+		    g_str_has_prefix (icon_name, "/")) {
 			ai_app_validate_add (helper,
 					     AS_PROBLEM_KIND_TAG_INVALID,
 					     "cached icon is a filename [%s]",
@@ -757,12 +759,12 @@ as_app_validate_screenshots (AsApp *app, AsAppValidateHelper *helper)
 	}
 
 	/* firmware does not need screenshots */
-	if (as_app_get_kind (app) == AS_APP_KIND_FIRMWARE)
+	if (as_app_get_kind (app) == AS_APP_KIND_FIRMWARE ||
+	    as_app_get_kind (app) == AS_APP_KIND_LOCALIZATION)
 		number_screenshots_min = 0;
 
 	/* metainfo and inf do not require any screenshots */
-	if (as_app_get_source_kind (app) == AS_APP_SOURCE_KIND_METAINFO ||
-	    as_app_get_source_kind (app) == AS_APP_SOURCE_KIND_INF)
+	if (as_app_get_source_kind (app) == AS_APP_SOURCE_KIND_METAINFO)
 		number_screenshots_min = 0;
 
 	/* only for AppData and AppStream */
