@@ -110,7 +110,7 @@ typedef enum {
  * @AS_APP_SUBSUME_FLAG_LANGUAGES:	Copy the languages
  * @AS_APP_SUBSUME_FLAG_NAME:		Copy the name
  * @AS_APP_SUBSUME_FLAG_COMMENT:	Copy the comment
- * @AS_APP_SUBSUME_FLAG_DEVELOPER_NAME	Copy the developer name
+ * @AS_APP_SUBSUME_FLAG_DEVELOPER_NAME:	Copy the developer name
  * @AS_APP_SUBSUME_FLAG_DESCRIPTION:	Copy the description
  * @AS_APP_SUBSUME_FLAG_METADATA:	Copy the metadata
  * @AS_APP_SUBSUME_FLAG_URL:		Copy the urls
@@ -127,41 +127,41 @@ typedef enum {
  **/
 typedef enum {
 	AS_APP_SUBSUME_FLAG_NONE		= 0,
-	AS_APP_SUBSUME_FLAG_NO_OVERWRITE	= 1lu << 0,	/* Since: 0.1.4 */
-	AS_APP_SUBSUME_FLAG_BOTH_WAYS		= 1lu << 1,	/* Since: 0.1.4 */
-	AS_APP_SUBSUME_FLAG_PARTIAL		= 1lu << 2,	/* Since: 0.2.2 */
-	AS_APP_SUBSUME_FLAG_KIND		= 1lu << 3,	/* Since: 0.6.1 */
-	AS_APP_SUBSUME_FLAG_STATE		= 1lu << 4,	/* Since: 0.6.1 */
-	AS_APP_SUBSUME_FLAG_BUNDLES		= 1lu << 5,	/* Since: 0.6.1 */
-	AS_APP_SUBSUME_FLAG_TRANSLATIONS	= 1lu << 6,	/* Since: 0.6.1 */
-	AS_APP_SUBSUME_FLAG_RELEASES		= 1lu << 7,	/* Since: 0.6.1 */
-	AS_APP_SUBSUME_FLAG_KUDOS		= 1lu << 8,	/* Since: 0.6.1 */
-	AS_APP_SUBSUME_FLAG_CATEGORIES		= 1lu << 9,	/* Since: 0.6.1 */
-	AS_APP_SUBSUME_FLAG_PERMISSIONS		= 1lu << 10,	/* Since: 0.6.1 */
-	AS_APP_SUBSUME_FLAG_EXTENDS		= 1lu << 11,	/* Since: 0.6.1 */
-	AS_APP_SUBSUME_FLAG_COMPULSORY		= 1lu << 12,	/* Since: 0.6.1 */
-	AS_APP_SUBSUME_FLAG_SCREENSHOTS		= 1lu << 13,	/* Since: 0.6.1 */
-	AS_APP_SUBSUME_FLAG_REVIEWS		= 1lu << 14,	/* Since: 0.6.1 */
-	AS_APP_SUBSUME_FLAG_CONTENT_RATINGS	= 1lu << 15,	/* Since: 0.6.1 */
-	AS_APP_SUBSUME_FLAG_PROVIDES		= 1lu << 16,	/* Since: 0.6.1 */
-	AS_APP_SUBSUME_FLAG_ICONS		= 1lu << 17,	/* Since: 0.6.1 */
-	AS_APP_SUBSUME_FLAG_MIMETYPES		= 1lu << 18,	/* Since: 0.6.1 */
-	AS_APP_SUBSUME_FLAG_VETOS		= 1lu << 19,	/* Since: 0.6.1 */
-	AS_APP_SUBSUME_FLAG_LANGUAGES		= 1lu << 20,	/* Since: 0.6.1 */
-	AS_APP_SUBSUME_FLAG_NAME		= 1lu << 21,	/* Since: 0.6.1 */
-	AS_APP_SUBSUME_FLAG_COMMENT		= 1lu << 22,	/* Since: 0.6.1 */
-	AS_APP_SUBSUME_FLAG_DEVELOPER_NAME	= 1lu << 23,	/* Since: 0.6.1 */
-	AS_APP_SUBSUME_FLAG_DESCRIPTION		= 1lu << 24,	/* Since: 0.6.1 */
-	AS_APP_SUBSUME_FLAG_METADATA		= 1lu << 25,	/* Since: 0.6.1 */
-	AS_APP_SUBSUME_FLAG_URL			= 1lu << 26,	/* Since: 0.6.1 */
-	AS_APP_SUBSUME_FLAG_KEYWORDS		= 1lu << 27,	/* Since: 0.6.1 */
-	AS_APP_SUBSUME_FLAG_SOURCE_FILE		= 1lu << 28,	/* Since: 0.6.1 */
-	AS_APP_SUBSUME_FLAG_BRANCH		= 1lu << 29,	/* Since: 0.6.1 */
-	AS_APP_SUBSUME_FLAG_ORIGIN		= 1lu << 30,	/* Since: 0.6.1 */
-	AS_APP_SUBSUME_FLAG_METADATA_LICENSE	= 1lu << 31,	/* Since: 0.6.1 */
-	AS_APP_SUBSUME_FLAG_PROJECT_LICENSE	= 1lu << 32,	/* Since: 0.6.1 */
-	AS_APP_SUBSUME_FLAG_PROJECT_GROUP	= 1lu << 33,	/* Since: 0.6.1 */
-	AS_APP_SUBSUME_FLAG_SOURCE_KIND		= 1lu << 34,	/* Since: 0.6.1 */
+	AS_APP_SUBSUME_FLAG_NO_OVERWRITE	= 1ull << 0,	/* Since: 0.1.4 */
+	AS_APP_SUBSUME_FLAG_BOTH_WAYS		= 1ull << 1,	/* Since: 0.1.4 */
+	AS_APP_SUBSUME_FLAG_PARTIAL		= 1ull << 2,	/* Since: 0.2.2 */
+	AS_APP_SUBSUME_FLAG_KIND		= 1ull << 3,	/* Since: 0.6.1 */
+	AS_APP_SUBSUME_FLAG_STATE		= 1ull << 4,	/* Since: 0.6.1 */
+	AS_APP_SUBSUME_FLAG_BUNDLES		= 1ull << 5,	/* Since: 0.6.1 */
+	AS_APP_SUBSUME_FLAG_TRANSLATIONS	= 1ull << 6,	/* Since: 0.6.1 */
+	AS_APP_SUBSUME_FLAG_RELEASES		= 1ull << 7,	/* Since: 0.6.1 */
+	AS_APP_SUBSUME_FLAG_KUDOS		= 1ull << 8,	/* Since: 0.6.1 */
+	AS_APP_SUBSUME_FLAG_CATEGORIES		= 1ull << 9,	/* Since: 0.6.1 */
+	AS_APP_SUBSUME_FLAG_PERMISSIONS		= 1ull << 10,	/* Since: 0.6.1 */
+	AS_APP_SUBSUME_FLAG_EXTENDS		= 1ull << 11,	/* Since: 0.6.1 */
+	AS_APP_SUBSUME_FLAG_COMPULSORY		= 1ull << 12,	/* Since: 0.6.1 */
+	AS_APP_SUBSUME_FLAG_SCREENSHOTS		= 1ull << 13,	/* Since: 0.6.1 */
+	AS_APP_SUBSUME_FLAG_REVIEWS		= 1ull << 14,	/* Since: 0.6.1 */
+	AS_APP_SUBSUME_FLAG_CONTENT_RATINGS	= 1ull << 15,	/* Since: 0.6.1 */
+	AS_APP_SUBSUME_FLAG_PROVIDES		= 1ull << 16,	/* Since: 0.6.1 */
+	AS_APP_SUBSUME_FLAG_ICONS		= 1ull << 17,	/* Since: 0.6.1 */
+	AS_APP_SUBSUME_FLAG_MIMETYPES		= 1ull << 18,	/* Since: 0.6.1 */
+	AS_APP_SUBSUME_FLAG_VETOS		= 1ull << 19,	/* Since: 0.6.1 */
+	AS_APP_SUBSUME_FLAG_LANGUAGES		= 1ull << 20,	/* Since: 0.6.1 */
+	AS_APP_SUBSUME_FLAG_NAME		= 1ull << 21,	/* Since: 0.6.1 */
+	AS_APP_SUBSUME_FLAG_COMMENT		= 1ull << 22,	/* Since: 0.6.1 */
+	AS_APP_SUBSUME_FLAG_DEVELOPER_NAME	= 1ull << 23,	/* Since: 0.6.1 */
+	AS_APP_SUBSUME_FLAG_DESCRIPTION		= 1ull << 24,	/* Since: 0.6.1 */
+	AS_APP_SUBSUME_FLAG_METADATA		= 1ull << 25,	/* Since: 0.6.1 */
+	AS_APP_SUBSUME_FLAG_URL			= 1ull << 26,	/* Since: 0.6.1 */
+	AS_APP_SUBSUME_FLAG_KEYWORDS		= 1ull << 27,	/* Since: 0.6.1 */
+	AS_APP_SUBSUME_FLAG_SOURCE_FILE		= 1ull << 28,	/* Since: 0.6.1 */
+	AS_APP_SUBSUME_FLAG_BRANCH		= 1ull << 29,	/* Since: 0.6.1 */
+	AS_APP_SUBSUME_FLAG_ORIGIN		= 1ull << 30,	/* Since: 0.6.1 */
+	AS_APP_SUBSUME_FLAG_METADATA_LICENSE	= 1ull << 31,	/* Since: 0.6.1 */
+	AS_APP_SUBSUME_FLAG_PROJECT_LICENSE	= 1ull << 32,	/* Since: 0.6.1 */
+	AS_APP_SUBSUME_FLAG_PROJECT_GROUP	= 1ull << 33,	/* Since: 0.6.1 */
+	AS_APP_SUBSUME_FLAG_SOURCE_KIND		= 1ull << 34,	/* Since: 0.6.1 */
 	/*< private >*/
 	AS_APP_SUBSUME_FLAG_LAST,
 } AsAppSubsumeFlags;
@@ -264,12 +264,12 @@ typedef enum {
  * The source kind.
  **/
 typedef enum {
-	AS_APP_SOURCE_KIND_UNKNOWN,			/* Since: 0.1.4 */
-	AS_APP_SOURCE_KIND_APPSTREAM,			/* Since: 0.1.4 */
-	AS_APP_SOURCE_KIND_DESKTOP,			/* Since: 0.1.4 */
-	AS_APP_SOURCE_KIND_APPDATA,			/* Since: 0.1.4 */
-	AS_APP_SOURCE_KIND_METAINFO,			/* Since: 0.1.7 */
-	AS_APP_SOURCE_KIND_INF,				/* Since: 0.3.5 */
+	AS_APP_SOURCE_KIND_UNKNOWN,		/* Since: 0.1.4 */
+	AS_APP_SOURCE_KIND_APPSTREAM,		/* Since: 0.1.4 */
+	AS_APP_SOURCE_KIND_DESKTOP,		/* Since: 0.1.4 */
+	AS_APP_SOURCE_KIND_APPDATA,		/* Since: 0.1.4 */
+	AS_APP_SOURCE_KIND_METAINFO,		/* Since: 0.1.7 */
+	AS_APP_SOURCE_KIND_INF,			/* Since: 0.3.5 (deprecated 0.6.2) */
 	/*< private >*/
 	AS_APP_SOURCE_KIND_LAST
 } AsAppSourceKind;
@@ -326,6 +326,7 @@ typedef enum {
  * @AS_APP_QUIRK_NOT_REVIEWABLE:	The app is not reviewable
  * @AS_APP_QUIRK_HAS_SHORTCUT:		The app has a shortcut in the system
  * @AS_APP_QUIRK_NOT_LAUNCHABLE:	The app is not launchable (run-able)
+ * @AS_APP_QUIRK_NEEDS_USER_ACTION:	The component requires some kind of user action
  *
  * The component attributes.
  **/
@@ -339,6 +340,7 @@ typedef enum {
 	AS_APP_QUIRK_NOT_REVIEWABLE	= 1 << 5,	/* Since: 0.5.14 */
 	AS_APP_QUIRK_HAS_SHORTCUT	= 1 << 6,	/* Since: 0.5.15 */
 	AS_APP_QUIRK_NOT_LAUNCHABLE	= 1 << 7,	/* Since: 0.5.15 */
+	AS_APP_QUIRK_NEEDS_USER_ACTION	= 1 << 8,	/* Since: 0.6.2 */
 	/*< private >*/
 	AS_APP_QUIRK_LAST
 } AsAppQuirk;
