@@ -114,6 +114,8 @@ typedef enum {
 
 #define	AS_NODE_ERROR				as_node_error_quark ()
 
+typedef GNode AsNode;
+
 GNode		*as_node_new			(void);
 GQuark		 as_node_error_quark		(void);
 void		 as_node_unref			(GNode		*node);
@@ -126,6 +128,8 @@ const gchar	*as_node_get_attribute		(const GNode	*node,
 						 const gchar	*key);
 gint		 as_node_get_attribute_as_int	(const GNode	*node,
 						 const gchar	*key);
+guint		 as_node_get_attribute_as_uint	(const GNode	*node,
+						 const gchar	*key);
 GHashTable	*as_node_get_localized		(const GNode	*node,
 						 const gchar	*key);
 const gchar	*as_node_get_localized_best	(const GNode	*node,
@@ -146,6 +150,9 @@ void		 as_node_add_attribute		(GNode		*node,
 void		 as_node_add_attribute_as_int	(GNode		*node,
 						 const gchar	*key,
 						 gint		 value);
+void		 as_node_add_attribute_as_uint	(GNode		*node,
+						 const gchar	*key,
+						 guint		 value);
 void		 as_node_remove_attribute	(GNode		*node,
 						 const gchar	*key);
 
@@ -192,6 +199,8 @@ void		 as_node_insert_hash		(GNode		*parent,
 						 GHashTable	*hash,
 						 AsNodeInsertFlags insert_flags);
 
+G_DEFINE_AUTOPTR_CLEANUP_FUNC(AsNode, as_node_unref)
+
 G_END_DECLS
 
 #endif /* __AS_NODE_H */
