@@ -475,7 +475,7 @@ _as_app_new_from_unique_id (const gchar *unique_id)
 		} else {
 			AsBundleKind kind = as_bundle_kind_from_string (split[1]);
 			if (kind != AS_BUNDLE_KIND_UNKNOWN) {
-				AsBundle *bundle = as_bundle_new ();
+				g_autoptr(AsBundle) bundle = as_bundle_new ();
 				as_bundle_set_kind (bundle, kind);
 				as_app_add_bundle (app, bundle);
 			}
@@ -1026,7 +1026,8 @@ as_store_add_app (AsStore *store, AsApp *app)
 
 		} else {
 			if (as_app_get_source_kind (app) == AS_APP_SOURCE_KIND_APPDATA &&
-			    as_app_get_source_kind (item) == AS_APP_SOURCE_KIND_APPSTREAM) {
+			    as_app_get_source_kind (item) == AS_APP_SOURCE_KIND_APPSTREAM &&
+			    as_app_get_scope (app) == AS_APP_SCOPE_SYSTEM) {
 				as_app_set_state (item, AS_APP_STATE_INSTALLED);
 				g_debug ("ignoring AppData entry as AppStream exists: %s:%s",
 					 as_app_get_unique_id (app),
@@ -1034,7 +1035,8 @@ as_store_add_app (AsStore *store, AsApp *app)
 				return;
 			}
 			if (as_app_get_source_kind (app) == AS_APP_SOURCE_KIND_DESKTOP &&
-			    as_app_get_source_kind (item) == AS_APP_SOURCE_KIND_APPSTREAM) {
+			    as_app_get_source_kind (item) == AS_APP_SOURCE_KIND_APPSTREAM &&
+			    as_app_get_scope (app) == AS_APP_SCOPE_SYSTEM) {
 				as_app_set_state (item, AS_APP_STATE_INSTALLED);
 				g_debug ("ignoring desktop entry as AppStream exists: %s:%s",
 					 as_app_get_unique_id (app),
@@ -2536,6 +2538,7 @@ as_store_load_installed (AsStore *store,
 			}
 		}
 		app = as_app_new ();
+		as_app_set_scope (app, scope);
 		if (!as_app_parse_file (app, filename, parse_flags, &error_local)) {
 			if (g_error_matches (error_local,
 					     AS_APP_ERROR,
@@ -2549,6 +2552,13 @@ as_store_load_installed (AsStore *store,
 			return FALSE;
 		}
 
+		/* don't match against non-package apps in the store */
+		if (scope == AS_APP_SCOPE_SYSTEM &&
+		    g_str_has_prefix (path, "/usr/share")) {
+			as_app_set_trust_flags (app, AS_APP_TRUST_FLAG_COMPLETE);
+			as_app_add_pkgname (app, "");
+		}
+
 		/* set the ID prefix */
 		if ((priv->add_flags & AS_STORE_ADD_FLAG_USE_UNIQUE_ID) == 0)
 			as_store_fixup_id_prefix (app, as_app_scope_to_string (scope));
@@ -2662,6 +2672,10 @@ as_store_search_per_system (AsStore *store,
 			g_debug ("skipping %s as invalid", data_dirs[i]);
 			continue;
 		}
+		if (g_str_has_prefix (data_dirs[i], "/home/")) {
+			g_debug ("skipping %s as invalid", data_dirs[i]);
+			continue;
+		}
 		if ((flags & AS_STORE_LOAD_FLAG_APP_INFO_SYSTEM) > 0) {
 			g_autofree gchar *dest = NULL;
 			dest = g_build_filename (data_dirs[i], "app-info", NULL);
